from collections import namedtuple

from reportserver.lib.io.requests import check_date, convert_german_date_to_iso, get_selected_options_from

GetRequest = namedtuple("GetRequest", "method GET session")
PostRequest = namedtuple("PostRequest", "method POST session")


def test_convert_wrong_date():
    result = check_date("1", "2017-01-01")
    expected = '2017-01-01'
    assert (result == expected)


def test_convert_correct_date():
    result = check_date("2016-01-01", "2017-01-01")
    expected = '2016-01-01'
    assert (result == expected)


def test_change_to_iso():
    result = convert_german_date_to_iso("01.01.2017")
    expected = '2017-01-01'
    assert (result == expected)


def test_change_to_iso_with_iso():
    result = convert_german_date_to_iso("2017-01-01")
    expected = '2017-01-01'
    assert (result == expected)


def test_get_filter_fields_no_dates():
    parameters = {}
    session = {
        "nuts1": [],
        "beneficiary": [],
        "regioncategory": []
    }
    request = GetRequest("GET", parameters, session)
    result = get_selected_options_from(request)
    assert (result.start == '2015-01-01')
    assert (result.end == '2017-06-01')
    assert (result.nuts1 is None)
    assert (result.regioncategory is None)
    assert (result.beneficiary is None)


def test_get_filter_fields_no_dates():
    parameters = {
        "startdate": "01.01.2017",
        "enddate": "2018-01-01"
    }
    session = {
        "nuts1": [],
        "beneficiary": [],
        "regioncategory": []
    }
    request = PostRequest("POST", parameters, session)
    result = get_selected_options_from(request)
    assert (result.start == '2017-01-01')
    assert (result.end == '2018-01-01')
    assert (result.nuts1 is None)
    assert (result.regioncategory is None)
    assert (result.beneficiary is None)

def test_get_filter_fields_fully_configured():
    parameters = {
        "startdate": "01.01.2017",
        "enddate": "2018-01-01",
        "nuts1": "DE1",
        "beneficiary": "1",
        "regioncategory": "1"
    }
    session = {
        "nuts1": [("DE1",1)],
        "beneficiary": [("1",1)],
        "regioncategory": [(1,1)]
    }
    request = PostRequest("POST", parameters, session)
    result = get_selected_options_from(request)
    assert (result.start == '2017-01-01')
    assert (result.end == '2018-01-01')
    assert (result.nuts1 == "DE1")
    assert (result.regioncategory == "1")
    assert (result.beneficiary == "1")
